// data/gametests/src/main.ts
import { world, system } from "@minecraft/server";
world.afterEvents.playerInteractWithBlock.subscribe((event) => {
  const location = event.faceLocation;
  const item = event.itemStack;
  const player = event.player;
  location.y += 1.2;
  if (!item && !player.isSneaking)
    return;
  if (!item && player.isSneaking) {
    player.runCommandAsync(`/tp @e[type=vb:backpack,tag=on_shoulder,c=1] ${location.x} ${location.y} ${location.z} facing @a[c=1]`);
    player.runCommandAsync("/tag @s remove has_backpack");
  } else if (item.typeId == "vb:backpack_leather" || item.typeId == "vb:backpack_iron" || item.typeId == "vb:backpack_gold" || item.typeId == "vb:backpack_diamond" || item.typeId == "vb:backpack_netherite") {
    player.onScreenDisplay.setActionBar({
      rawtext: [
        { translate: "action.hint.backpack.spawn" }
      ]
    });
  }
  return;
});
world.afterEvents.playerInteractWithEntity.subscribe((event) => {
  const player = event.player;
  const playerName = event.player.name;
  const target = event.target;
  const location = event.player.location;
  if (target.typeId == "vb:backpack_inventory" && !target.getProperty("vb:on_shoulder") && player.isSneaking && !player.hasTag("has_backpack")) {
    target.runCommandAsync(`/ride @e[type=vb:backpack,c=1,r=1] start_riding @a[name=${playerName}]`);
    player.runCommandAsync("/tag @s add has_backpack");
    player.onScreenDisplay.setActionBar({
      rawtext: [
        { translate: "action.hint.backpack.unequip" }
      ]
    });
  } else if (target.typeId == "vb:backpack_inventory" && !target.getProperty("vb:on_shoulder") && player.isSneaking && player.hasTag("has_backpack")) {
    player.onScreenDisplay.setActionBar({
      rawtext: [
        { translate: "action.hint.backpack.with_other_backpack" }
      ]
    });
    player.runCommand("/playsound note.bassattack @s ~~~ 0.4 0.7");
  } else if (target.typeId == "vb:backpack_inventory" && !target.getProperty("vb:on_shoulder") && !player.isSneaking) {
    player.runCommand(`/execute positioned ~ ~ ~ run playsound armor.equip_leather @a ${location.x} ${location.y} ${location.z}`);
    target.runCommand("/playanimation @e[c=1,type=vb:backpack] animation.backpack.open");
  } else if (target.typeId == "vb:backpack_inventory" && target.getProperty("vb:on_shoulder") && !player.isSneaking) {
    player.runCommand(`/execute positioned ~ ~ ~ run playsound armor.equip_leather @a ${location.x} ${location.y} ${location.z}`);
  }
});
world.afterEvents.entityDie.subscribe((event) => {
  const entity = event.deadEntity;
  const location = event.deadEntity.location;
  if (entity.typeId != "minecraft:player")
    return;
  if (entity.typeId == "minecraft:player") {
    entity.runCommandAsync("/tag @s remove has_backpack");
  }
});
world.afterEvents.playerSpawn.subscribe((event) => {
  const player = event.player;
  if (player) {
    player.runCommandAsync("/tag @s remove has_backpack");
    player.runCommandAsync("/ride @s evict_riders");
  }
});
system.runInterval(() => {
  world.getAllPlayers().forEach((player) => {
    player.runCommandAsync("/execute as @s[m=spectator] at @s run tag @s remove has_backpack");
  });
}, 5);
